# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from keystoneauth1 import identity
from keystoneauth1 import loading
from keystoneauth1.loading._plugins.identity import base


class BaseV2Loader(base.BaseIdentityLoader):

    def get_options(self):
        options = super(BaseV2Loader, self).get_options()

        options.extend([
            loading.Opt('tenant-id', help='Tenant ID'),
            loading.Opt('tenant-name', help='Tenant Name'),
            loading.Opt('trust-id', help='Trust ID'),
        ])

        return options


class Token(BaseV2Loader):

    @property
    def plugin_class(self):
        return identity.V2Token

    def get_options(self):
        options = super(Token, self).get_options()

        options.extend([
            loading.Opt('token', secret=True, help='Token'),
        ])

        return options


class Password(BaseV2Loader):

    @property
    def plugin_class(self):
        return identity.V2Password

    def get_options(self):
        options = super(Password, self).get_options()

        options.extend([
            loading.Opt('user-name',
                       dest='username',
                       deprecated=[loading.Opt('username')],
                       help='Username to login with'),
            loading.Opt('user-id', help='User ID to longin with'),
            loading.Opt('password', secret=True, help='Password to use'),
        ])

        return options
